@@ -164,7 +164,7 @@ class category_index
 		return result;
 	}
 
-	size_t size() const;
+	std::size_t size() const;
 	//	bool isValid() const;
 
   private:
@@ -475,12 +475,12 @@ category_index::entry *category_index::erase(category &cat, entry *h, row *k)
 	return fix_up(h);
 }
 
-size_t category_index::size() const
+std::size_t category_index::size() const
 {
 	std::stack<entry *> s;
 	s.push(m_root);
 
-	size_t result = 0;
+	std::size_t result = 0;
 
 	while (not s.empty())
 	{
@@ -521,71 +521,18 @@ category::category(const category &rhs)
 		m_index = new category_index(*this);
 }
 
-category::category(category &&rhs)
-	: m_name(std::move(rhs.m_name))
-	, m_items(std::move(rhs.m_items))
-	, m_validator(rhs.m_validator)
-	, m_cat_validator(rhs.m_cat_validator)
-	, m_parent_links(std::move(rhs.m_parent_links))
-	, m_child_links(std::move(rhs.m_child_links))
-	, m_cascade(rhs.m_cascade)
-	, m_index(rhs.m_index)
-	, m_head(rhs.m_head)
-	, m_tail(rhs.m_tail)
+void swap(category &a, category &b) noexcept
 {
-	rhs.m_head = nullptr;
-	rhs.m_tail = nullptr;
-	rhs.m_index = nullptr;
-}
-
-category &category::operator=(const category &rhs)
-{
-	if (this != &rhs)
-	{
-		if (not empty())
-			clear();
-
-		m_name = rhs.m_name;
-		m_items = rhs.m_items;
-		m_cascade = rhs.m_cascade;
-
-		m_validator = nullptr;
-		m_cat_validator = nullptr;
-
-		delete m_index;
-		m_index = nullptr;
-
-		for (auto r = rhs.m_head; r != nullptr; r = r->m_next)
-			insert_impl(cend(), clone_row(*r));
-
-		m_validator = rhs.m_validator;
-		m_cat_validator = rhs.m_cat_validator;
-
-		if (m_cat_validator != nullptr and m_index == nullptr)
-			m_index = new category_index(*this);
-	}
-
-	return *this;
-}
-
-category &category::operator=(category &&rhs)
-{
-	if (this != &rhs)
-	{
-		m_name = std::move(rhs.m_name);
-		m_items = std::move(rhs.m_items);
-		m_cascade = rhs.m_cascade;
-		m_validator = rhs.m_validator;
-		m_cat_validator = rhs.m_cat_validator;
-		m_parent_links = rhs.m_parent_links;
-		m_child_links = rhs.m_child_links;
-
-		std::swap(m_index, rhs.m_index);
-		std::swap(m_head, rhs.m_head);
-		std::swap(m_tail, rhs.m_tail);
-	}
-
-	return *this;
+	std::swap(a.m_name, b.m_name);
+	std::swap(a.m_items, b.m_items);
+	std::swap(a.m_validator, b.m_validator);
+	std::swap(a.m_cat_validator, b.m_cat_validator);
+	std::swap(a.m_parent_links, b.m_parent_links);
+	std::swap(a.m_child_links, b.m_child_links);
+	std::swap(a.m_cascade, b.m_cascade);
+	std::swap(a.m_index, b.m_index);
+	std::swap(a.m_head, b.m_head);
+	std::swap(a.m_tail, b.m_tail);
 }
 
 category::~category()
@@ -597,7 +544,7 @@ category::~category()
 
 void category::remove_item(std::string_view item_name)
 {
-	for (size_t ix = 0; ix < m_items.size(); ++ix)
+	for (std::size_t ix = 0; ix < m_items.size(); ++ix)
 	{
 		if (not iequals(item_name, m_items[ix].m_name))
 			continue;
@@ -616,7 +563,7 @@ void category::remove_item(std::string_view item_name)
 
 void category::rename_item(std::string_view from_name, std::string_view to_name)
 {
-	for (size_t ix = 0; ix < m_items.size(); ++ix)
+	for (std::size_t ix = 0; ix < m_items.size(); ++ix)
 	{
 		if (not iequals(from_name, m_items[ix].m_name))
 			continue;
@@ -719,7 +666,7 @@ void category::set_validator(const validator *v, datablock &db)
 	update_links(db);
 }
 
-void category::update_links(datablock &db)
+void category::update_links(const datablock &db)
 {
 	m_child_links.clear();
 	m_parent_links.clear();
@@ -728,7 +675,7 @@ void category::update_links(datablock &db)
 	{
 		for (auto link : m_validator->get_links_for_parent(m_name))
 		{
-			auto childCat = db.get(link->m_child_category);
+			auto childCat = const_cast<category *>(db.get(link->m_child_category));
 			if (childCat == nullptr)
 				continue;
 			m_child_links.emplace_back(childCat, link);
@@ -736,7 +683,7 @@ void category::update_links(datablock &db)
 
 		for (auto link : m_validator->get_links_for_child(m_name))
 		{
-			auto parentCat = db.get(link->m_parent_category);
+			auto parentCat = const_cast<category *>(db.get(link->m_parent_category));
 			if (parentCat == nullptr)
 				continue;
 			m_parent_links.emplace_back(parentCat, link);
@@ -844,7 +791,7 @@ bool category::is_valid() const
 
 				iv->validate_value(vi->text(), ec);
 
-				if (ec != std::errc())
+				if ((bool)ec)
 				{
 					m_validator->report_error(ec, m_name, m_items[cix].m_name, false);
 					continue;
@@ -885,7 +832,7 @@ bool category::validate_links() const
 		if (name() == "atom_site" and (parent->name() == "pdbx_poly_seq_scheme" or parent->name() == "entity_poly_seq"))
 			continue;
 
-		size_t missing = 0;
+		std::size_t missing = 0;
 		category first_missing_rows(name());
 
 		for (auto r : *this)
@@ -962,7 +909,7 @@ condition category::get_parents_condition(row_handle rh, const category &parentC
 		{
 			condition cond;
 
-			for (size_t ix = 0; ix < link->m_child_keys.size(); ++ix)
+			for (std::size_t ix = 0; ix < link->m_child_keys.size(); ++ix)
 			{
 				auto childValue = rh[link->m_child_keys[ix]];
 
@@ -1004,7 +951,7 @@ condition category::get_children_condition(row_handle rh, const category &childC
 		{
 			condition cond;
 
-			for (size_t ix = 0; ix < link->m_parent_keys.size(); ++ix)
+			for (std::size_t ix = 0; ix < link->m_parent_keys.size(); ++ix)
 			{
 				auto childKey = link->m_child_keys[ix];
 				auto parentKey = link->m_parent_keys[ix];
@@ -1180,14 +1127,14 @@ class save_value
 	const T m_sv;
 };
 
-size_t category::erase(condition &&cond)
+std::size_t category::erase(condition &&cond)
 {
 	return erase(std::move(cond), {});
 }
 
-size_t category::erase(condition &&cond, std::function<void(row_handle)> &&visit)
+std::size_t category::erase(condition &&cond, std::function<void(row_handle)> &&visit)
 {
-	size_t result = 0;
+	std::size_t result = 0;
 
 	cond.prepare(*this);
 
@@ -1327,7 +1274,7 @@ std::string category::get_unique_value(std::string_view item_name)
 	if (result.empty())
 	{
 		// brain-dead implementation
-		for (size_t ix = 0; ix < size(); ++ix)
+		for (std::size_t ix = 0; ix < size(); ++ix)
 		{
 			// result = m_name + "-" + std::to_string(ix);
 			result = cif_id_for_number(ix);
@@ -1384,7 +1331,7 @@ void category::update_value(const std::vector<row_handle> &rows, std::string_vie
 			condition cond;
 			std::string childItemName;
 
-			for (size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
+			for (std::size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
 			{
 				std::string pk = linked->m_parent_keys[ix];
 				std::string ck = linked->m_child_keys[ix];
@@ -1415,7 +1362,7 @@ void category::update_value(const std::vector<row_handle> &rows, std::string_vie
 			{
 				condition cond_c;
 
-				for (size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
+				for (std::size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
 				{
 					std::string pk = linked->m_parent_keys[ix];
 					std::string ck = linked->m_child_keys[ix];
@@ -1433,7 +1380,7 @@ void category::update_value(const std::vector<row_handle> &rows, std::string_vie
 				// oops, we need to split this child, unless a row already exists for the new value
 				condition check;
 
-				for (size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
+				for (std::size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
 				{
 					std::string pk = linked->m_parent_keys[ix];
 					std::string ck = linked->m_child_keys[ix];
@@ -1529,7 +1476,7 @@ void category::update_value(row *row, uint16_t item, std::string_view value, boo
 			condition cond;
 			std::string childItemName;
 
-			for (size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
+			for (std::size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
 			{
 				std::string pk = linked->m_parent_keys[ix];
 				std::string ck = linked->m_child_keys[ix];
@@ -1566,7 +1513,7 @@ void category::update_value(row *row, uint16_t item, std::string_view value, boo
 
 			condition cond_n;
 
-			for (size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
+			for (std::size_t ix = 0; ix < linked->m_parent_keys.size(); ++ix)
 			{
 				std::string pk = linked->m_parent_keys[ix];
 				std::string ck = linked->m_child_keys[ix];
@@ -1712,7 +1659,7 @@ category::iterator category::insert_impl(const_iterator pos, row *n)
 			m_index->insert(*this, n);
 
 		// insert at end, most often this is the case
-		if (pos.m_current == nullptr)
+		if (pos.m_current.m_row == nullptr)
 		{
 			if (m_head == nullptr)
 				m_tail = m_head = n;
@@ -1723,7 +1670,7 @@ category::iterator category::insert_impl(const_iterator pos, row *n)
 		{
 			assert(m_head != nullptr);
 
-			if (pos.m_current == m_head)
+			if (pos.m_current.m_row == m_head)
 				m_head = n->m_next = m_head;
 			else
 				n = n->m_next = m_head->m_next;
@@ -1773,7 +1720,7 @@ void category::sort(std::function<int(row_handle, row_handle)> f)
 	m_tail = rows.back().get_row();
 
 	auto r = m_head;
-	for (size_t i = 1; i < rows.size(); ++i)
+	for (std::size_t i = 1; i < rows.size(); ++i)
 		r = r->m_next = rows[i].get_row();
 	r->m_next = nullptr;
 
@@ -1789,7 +1736,7 @@ void category::reorder_by_index()
 
 namespace detail
 {
-	size_t write_value(std::ostream &os, std::string_view value, size_t offset, size_t width, bool right_aligned)
+	std::size_t write_value(std::ostream &os, std::string_view value, std::size_t offset, std::size_t width, bool right_aligned)
 	{
 		if (value.find('\n') != std::string::npos or width == 0 or value.length() > 132) // write as text item
 		{
@@ -1950,7 +1897,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 	{
 		os << "loop_\n";
 
-		std::vector<size_t> itemWidths(m_items.size());
+		std::vector<std::size_t> itemWidths(m_items.size());
 
 		for (auto cix : order)
 		{
@@ -1972,7 +1919,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 
 				if (v->text().find('\n') == std::string_view::npos)
 				{
-					size_t l = v->text().length();
+					std::size_t l = v->text().length();
 
 					if (not sac_parser::is_unquoted_string(v->text()))
 						l += 2;
@@ -1988,11 +1935,11 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 
 		for (auto r = m_head; r != nullptr; r = r->m_next) // loop over rows
 		{
-			size_t offset = 0;
+			std::size_t offset = 0;
 
 			for (uint16_t cix : order)
 			{
-				size_t w = itemWidths[cix];
+				std::size_t w = itemWidths[cix];
 
 				std::string_view s;
 				auto iv = r->get(cix);
@@ -2002,7 +1949,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 				if (s.empty())
 					s = "?";
 
-				size_t l = s.length();
+				std::size_t l = s.length();
 				if (not sac_parser::is_unquoted_string(s))
 					l += 2;
 				if (l < w)
@@ -2030,7 +1977,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 	else
 	{
 		// first find the indent level
-		size_t l = 0;
+		std::size_t l = 0;
 
 		for (auto &col : m_items)
 		{
@@ -2042,7 +1989,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 
 		l += 3;
 
-		size_t width = 1;
+		std::size_t width = 1;
 
 		for (auto cix : order)
 		{
@@ -2057,7 +2004,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 			if (s.empty())
 				s = "?";
 
-			size_t l2 = s.length();
+			std::size_t l2 = s.length();
 
 			if (not sac_parser::is_unquoted_string(s))
 				l2 += 2;
@@ -2083,7 +2030,7 @@ void category::write(std::ostream &os, const std::vector<uint16_t> &order, bool
 			if (s.empty())
 				s = "?";
 
-			size_t offset = l;
+			std::size_t offset = l;
 			if (s.length() + l >= kMaxLineLength)
 			{
 				os << '\n';
@@ -2123,7 +2070,7 @@ bool category::operator==(const category &rhs) const
 	typedef std::function<int(std::string_view, std::string_view)> compType;
 	std::vector<std::tuple<std::string, compType>> item_names;
 	std::vector<std::string> keys;
-	std::vector<size_t> keyIx;
+	std::vector<std::size_t> keyIx;
 
 	if (catValidator == nullptr)
 	{
