@@ -92,6 +92,70 @@ condition get_condition(residue_key_type &k)
 
 // --------------------------------------------------------------------
 
+void checkEntities(datablock &db)
+{
+	using namespace cif::literals;
+
+	auto &cf = cif::compound_factory::instance();
+
+	for (auto entity : db["entity"].find("formula_weight"_key == null or "formula_weight"_key == 0))
+	{
+		const auto &[entity_id, type] = entity.get<std::string, std::string>("id", "type");
+
+		float formula_weight = 0;
+
+		if (type == "polymer")
+		{
+			int n = 0;
+
+			for (std::string comp_id : db["pdbx_poly_seq_scheme"].find<std::string>("entity_id"_key == entity_id, "mon_id"))
+			{
+				auto compound = cf.create(comp_id);
+				assert(compound);
+				if (not compound)
+					throw std::runtime_error("missing information for compound " + comp_id);
+				formula_weight += compound->formula_weight();
+				++n;
+			}
+
+			formula_weight -= (n - 1) * 18.015;
+		}
+		else if (type == "water")
+			formula_weight = 18.015;
+		else if (type == "branched")
+		{
+			int n = 0;
+
+			for (std::string comp_id : db["pdbx_entity_branch_list"].find<std::string>("entity_id"_key == entity_id, "comp_id"))
+			{
+				auto compound = cf.create(comp_id);
+				assert(compound);
+				if (not compound)
+					throw std::runtime_error("missing information for compound " + comp_id);
+				formula_weight += compound->formula_weight();
+				++n;
+			}
+
+			formula_weight -= (n - 1) * 18.015;
+		}
+		else if (type == "non-polymer")
+		{
+			auto comp_id = db["pdbx_nonpoly_scheme"].find_first<std::optional<std::string>>("entity_id"_key == entity_id, "mon_id");
+			if (comp_id.has_value())
+			{
+				auto compound = cf.create(*comp_id);
+				assert(compound);
+				if (not compound)
+					throw std::runtime_error("missing information for compound " + *comp_id);
+				formula_weight = compound->formula_weight();
+			}
+		}
+
+		if (formula_weight > 0)
+			entity.assign({ { "formula_weight", formula_weight, 3 } });
+	}
+}
+
 void createEntityIDs(datablock &db)
 {
 	// Suppose the file does not have entity ID's. We have to make up some
@@ -147,11 +211,11 @@ void createEntityIDs(datablock &db)
 		lastSeqID = seq_id;
 	}
 
-	std::map<size_t, std::string> entity_ids;
+	std::map<std::size_t, std::string> entity_ids;
 
 	atom_site.add_item("label_entity_id");
 
-	for (size_t i = 0; i < entities.size(); ++i)
+	for (std::size_t i = 0; i < entities.size(); ++i)
 	{
 		if (entity_ids.contains(i))
 			continue;
@@ -159,14 +223,14 @@ void createEntityIDs(datablock &db)
 		auto entity_id = std::to_string(i + 1);
 		entity_ids[i] = entity_id;
 
-		for (size_t j = i + 1; j < entities.size(); ++j)
+		for (std::size_t j = i + 1; j < entities.size(); ++j)
 		{
 			if (entities[i] == entities[j])
 				entity_ids[j] = entity_id;
 		}
 	}
 
-	for (size_t ix = 0; auto &e : entities)
+	for (std::size_t ix = 0; auto &e : entities)
 	{
 		auto k = e.front();
 		const auto &entity_id = entity_ids[ix++];
@@ -348,6 +412,10 @@ void checkAtomRecords(datablock &db)
 	if (atom_site.contains(key("label_seq_id") < 0))
 		fixNegativeSeqID(atom_site);
 
+	std::set<int> polymer_entities;
+	for (int id : db["entity"].find<int>("type"_key == "polymer", "id"))
+		polymer_entities.insert(id);
+
 	for (auto row : atom_site)
 	{
 		residue_key_type k = row.get<std::optional<std::string>,
@@ -378,7 +446,7 @@ void checkAtomRecords(datablock &db)
 		std::string asym_id = get_asym_id(k);
 		std::string comp_id = get_comp_id(k);
 
-		bool is_peptide = cf.is_peptide(comp_id);
+		bool is_polymer = polymer_entities.contains(row["label_entity_id"].as<int>());
 		auto compound = cf.create(comp_id);
 
 		if (not compound)
@@ -386,12 +454,16 @@ void checkAtomRecords(datablock &db)
 
 		auto chem_comp_entry = chem_comp.find_first("id"_key == comp_id);
 
+		std::optional<bool> non_std;
+		if  (cf.is_monomer(comp_id))
+			non_std = cf.is_std_monomer(comp_id);
+
 		if (not chem_comp_entry)
 		{
 			chem_comp.emplace({ //
 				{ "id", comp_id },
 				{ "type", compound->type() },
-				{ "mon_nstd_flag", cf.is_std_monomer(comp_id) ? "y" : "n" },
+				{ "mon_nstd_flag", non_std },
 				{ "name", compound->name() },
 				{ "formula", compound->formula() },
 				{ "formula_weight", compound->formula_weight() } });
@@ -402,8 +474,8 @@ void checkAtomRecords(datablock &db)
 
 			if (not chem_comp_entry["type"])
 				items.emplace_back(item{ "type", compound->type() });
-			if (not chem_comp_entry["mon_nstd_flag"])
-				items.emplace_back(item{ "mon_nstd_flag", cf.is_std_monomer(comp_id) ? "y" : "n" });
+			if (not chem_comp_entry["mon_nstd_flag"] and non_std.has_value())
+				items.emplace_back(item{ "mon_nstd_flag", non_std });
 			if (not chem_comp_entry["name"])
 				items.emplace_back(item{ "name", compound->name() });
 			if (not chem_comp_entry["formula"])
@@ -415,20 +487,18 @@ void checkAtomRecords(datablock &db)
 				chem_comp_entry.assign(items);
 		}
 
-		if (is_peptide and not has_seq_id(k))
+		if (is_polymer and not has_seq_id(k))
 			throw std::runtime_error("atom_site record has peptide comp_id but no sequence number, cannot continue");
 
 		int seq_id = get_seq_id(k);
 
-		if (row["label_seq_id"].empty())
+		if (is_polymer and row["label_seq_id"].empty() and cf.is_monomer(comp_id))
 			row["label_seq_id"] = std::to_string(seq_id);
 
 		if (row["label_atom_id"].empty())
 			row["label_atom_id"] = row["auth_atom_id"].text();
 		if (row["label_asym_id"].empty())
 			row["label_asym_id"] = row["auth_asym_id"].text();
-		if (row["label_seq_id"].empty())
-			row["label_seq_id"] = row["auth_seq_id"].text();
 		if (row["label_comp_id"].empty())
 			row["label_comp_id"] = row["auth_comp_id"].text();
 		if (row["label_atom_id"].empty())
@@ -448,14 +518,14 @@ void checkAtomRecords(datablock &db)
 
 			float v;
 			auto s = row.get<std::string>(item_name);
-			if (auto [ptr, ec] = cif::from_chars(s.data(), s.data() + s.length(), v); ec != std::errc())
+			if (auto [ptr, ec] = cif::from_chars(s.data(), s.data() + s.length(), v); (bool)ec)
 				continue;
 
 			if (s.length() < prec + 1 or s[s.length() - prec - 1] != '.')
 			{
 				char b[12];
 
-				if (auto [ptr, ec] = cif::to_chars(b, b + sizeof(b), v, cif::chars_format::fixed, prec); ec == std::errc())
+				if (auto [ptr, ec] = cif::to_chars(b, b + sizeof(b), v, cif::chars_format::fixed, prec); (bool)ec)
 					row.assign(item_name, { b, static_cast<std::string::size_type>(ptr - b) }, false, false);
 			}
 		}
@@ -517,7 +587,7 @@ void checkAtomAnisotropRecords(datablock &db)
 		{
 			if (cif::VERBOSE and std::exchange(warnReplaceTypeSymbol, false))
 				std::clog << "Replacing type_symbol in atom_site_anisotrop record(s)\n";
-			row["type_symbol"] != parent["type_symbol"].text();
+			row["type_symbol"] = parent["type_symbol"].text();
 		}
 
 		if (row["pdbx_auth_alt_id"].empty())
@@ -1068,7 +1138,7 @@ bool reconstruct_pdbx(file &file, std::string_view dictionary)
 				              iv->m_type != nullptr and
 				              iv->m_type->m_primitive_type == cif::DDL_PrimitiveType::Numb;
 
-				for (size_t ix = 0; auto row : cat)
+				for (std::size_t ix = 0; auto row : cat)
 				{
 					if (number)
 						row.assign(key, std::to_string(++ix), false, false);
@@ -1263,6 +1333,9 @@ bool reconstruct_pdbx(file &file, std::string_view dictionary)
 	if (db.get("entity") == nullptr)
 		createEntity(db);
 
+	// fill in missing formula_weight, e.g.
+	checkEntities(db);
+
 	if (db.get("pdbx_poly_seq_scheme") == nullptr)
 		createPdbxPolySeqScheme(db);
 
